@@ -30,7 +30,7 @@ sub edit {
       : $page->content;
     $content ||= $self->config->default_content;
     $self->render_screen(
-        screen_title => $page->id,
+        screen_title => $page->title,
         page_content => $content,
         page_time => $page->modified_time,
     );
@@ -40,11 +40,11 @@ sub save {
     my $page = $self->pages->current;
     $page->content($self->cgi->page_content);
     if ($page->modified_time != $self->cgi->page_time) {
-        my $page_id = $page->id;
-        return $self->redirect("action=edit_contention&page_id=$page_id");
+        my $page_uri = $page->uri;
+        return $self->redirect("action=edit_contention&page_id=$page_uri");
     }
     $page->update->store;
-    return $self->redirect($page->id);
+    return $self->redirect($page->uri);
 }
 
 sub preview {
@@ -103,7 +103,7 @@ default_content: Enter your own page content here.
 __template/tt2/edit_button.html__
 <!-- BEGIN edit_button.html -->
 [% rev_id = hub.revisions.revision_id %]
-<a href="[% script_name %]?action=edit&page_id=[% page_id %][% IF rev_id %]&revision_id=[% rev_id %][% END %]" accesskey="e" title="Edit This Page">
+<a href="[% script_name %]?action=edit&page_id=[% page_uri %][% IF rev_id %]&revision_id=[% rev_id %][% END %]" accesskey="e" title="Edit This Page">
 [% INCLUDE edit_button_icon.html %]
 </a>
 <!-- END edit_button.html -->
@@ -145,7 +145,7 @@ function clear_default_content(content_box) {
 <br />
 <br />
 <input type="hidden" name="action" value="edit" />
-<input type="hidden" name="page_id" value="[% page_id %]" />
+<input type="hidden" name="page_id" value="[% page_uri %]" />
 <input type="hidden" name="page_time" value="[% page_time %]" />
 <textarea name="page_content" rows="25" cols="80" onfocus="clear_default_content(this)">
 [%- page_content -%]
